<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\Order;
use Illuminate\Http\Request;

class CartController extends Controller
{
    public function addToCart(Request $request)
    {
        try {
            $request->validate([
                'product_id' => 'required|exists:products,id',
                'quantity' => 'required|integer|min:1'
            ]);

            $user = $request->user();

            $cartItem = Cart::where('user_id', $user->id)
                ->where('product_id', $request->product_id)
                ->first();

            if ($cartItem) {
                $cartItem->quantity += $request->quantity;
                $cartItem->save();

                return response()->json([
                    'success' => true,
                    'message' => 'Product quantity updated in cart',
                    'data' => $cartItem
                ]);
            } else {
                $cartItem = Cart::create([
                    'user_id' => $user->id,
                    'product_id' => $request->product_id,
                    'quantity' => $request->quantity,
                    'order_number' => null
                ]);

                return response()->json([
                    'success' => true,
                    'message' => 'Product added to cart',
                    'data' => $cartItem
                ]);
            }
        } catch (\Throwable $e) {
            return response()->json([
                'success' => false,
                'message' => $e->getMessage(),
                'data' => []
            ]);
        }
    }


   
     public function getUserCart()
    {
        $userCart = Cart::where('user_id', request()->user()->id)->whereNull('order_number')->with('product.brand')->with('product.images')->get();
        return response()->json(['success' => true, 'message' => 'user cart', 'data' => $userCart]);
    }

    public function checkout(Request $request)
    {

        // Get user's cart items
        $cartItems = Cart::where('user_id', $request->user()->id)->get();

        if ($cartItems->isEmpty()) {
            return response()->json(['message' => 'Your cart is empty.'], 400);
        }

        // Calculate total price and total products
        $totalPrice = 0;
        $totalProducts = 0;

        foreach ($cartItems as $cartItem) {
            $totalPrice += $cartItem->product->price * $cartItem->quantity; // Assuming product has a price attribute
            $totalProducts += $cartItem->quantity;
        }

        // Create a new order
        $order = Order::create([
            'user_id' => $request->user()->id,
            'order_ref' => uniqid('order_'), // Generate a unique order reference
            'total_price' => $totalPrice,
            'total_products' => $totalProducts,
            'payment_method' => $request->payment_method,
            'status' =>  Order::STATUS_PROCESSING
        ]);

        // Update cart items with the order number
        foreach ($cartItems as $cartItem) {
            $cartItem->update(['order_number' => $order->id]);
        }

        $data = (object) [
            'order_id' => $order->id,
            'order_ref' => $order->order_ref,
            'total_price' => $totalPrice,
            'total_products' => $totalProducts
        ];

        return response()->json([
            'success' => true,
            'message' => 'Checkout successful.',
            'data' => $data
        ]);
    }
    
    
    
    public function deleteUserCart(Request $request, $id)
    {
        $cartItem = Cart::where('user_id', $request->user()->id)
            ->where('id', $id)
            ->first();

        // Check if the item exists
        if (!$cartItem) {
            return response()->json([
                'success' => false,
                'message' => 'Cart item not found',
                'data' => []
            ], 404);
        }

        // Delete the cart item
        $cartItem->delete();

        return response()->json([
            'success' => true,
            'message' => 'Cart item deleted successfully',
            'data' => []
        ]);
    }
}
